@@ -22,40 +22,40 @@
 ****************************************************************************/
 
 #include "preferencesdialog.h"
-
+#include "krdc_debug.h"
 #include "hostpreferenceslist.h"
 #include "ui_general.h"
 
-#include <KConfigSkeleton>
-#include <KDebug>
-#include <KPluginSelector>
-#include <KService>
-#include <KServiceTypeTrader>
-#include <KPluginInfo>
+#include <KConfigGui/KConfigSkeleton>
+#include <KLocalizedString>
+#include <KCMUtils/KPluginSelector>
+#include <KPluginTrader>
+#include <KService/KPluginInfo>
 
 PreferencesDialog::PreferencesDialog(QWidget *parent, KConfigSkeleton *skeleton)
-        : KConfigDialog(parent, "preferences", skeleton)
+        : KConfigDialog(parent, QLatin1String("preferences"), skeleton)
         , m_settingsChanged(false)
 {
     QWidget *generalPage = new QWidget(this);
     Ui::General generalUi;
     generalUi.setupUi(generalPage);
-    addPage(generalPage, i18nc("General Config", "General"), "krdc", i18n("General Configuration"));
+    addPage(generalPage, i18nc("General Config", "General"), QLatin1String("krdc"), i18n("General Configuration"));
 
     HostPreferencesList *hostPreferencesList = new HostPreferencesList(this,
                                                                        qobject_cast<MainWindow *>(parent),
                                                                        skeleton->config()->group("hostpreferences"));
-    addPage(hostPreferencesList, i18n("Hosts"), "computer", i18n("Host Configuration"));
+    addPage(hostPreferencesList, i18n("Hosts"), QLatin1String("computer"), i18n("Host Configuration"));
 
     m_pluginSelector = new KPluginSelector();
-    KService::List offers = KServiceTypeTrader::self()->query("KRDC/Plugin");
-    m_pluginSelector->addPlugins(KPluginInfo::fromServices(offers), KPluginSelector::ReadConfigFile,
-                               i18n("Plugins"), "Service", KGlobal::config());
+    const KPluginInfo::List  offers = KPluginTrader::self()->query(QLatin1String("krdc"));
+    m_pluginSelector->addPlugins(offers, KPluginSelector::ReadConfigFile,
+                                    i18n("Plugins"), QLatin1String("Service"), KSharedConfig::openConfig());
     m_pluginSelector->load();
-    addPage(m_pluginSelector, i18n("Plugins"), "preferences-plugin", i18n("Plugin Configuration"));
+    addPage(m_pluginSelector, i18n("Plugins"), QLatin1String("preferences-plugin"), i18n("Plugin Configuration"));
 
     connect(this, SIGNAL(accepted()), SLOT(saveState()));
-    connect(this, SIGNAL(defaultClicked()), SLOT(loadDefaults()));
+    QPushButton *defaultsButton = buttonBox()->button(QDialogButtonBox::RestoreDefaults);
+    connect(defaultsButton, SIGNAL(clicked()), SLOT(loadDefaults()));
     connect(m_pluginSelector, SIGNAL(changed(bool)), SLOT(settingsChanged()));
 }
 
@@ -68,16 +68,24 @@ void PreferencesDialog::saveState()
 void PreferencesDialog::loadDefaults()
 {
     m_pluginSelector->defaults();
-    enableButton(Default, false);
 }
 
 void PreferencesDialog::settingsChanged()
 {
-    enableButton(Apply, true);
-    enableButton(Default, true);
+    enableButton(QDialogButtonBox::Apply);
+    enableButton(QDialogButtonBox::RestoreDefaults);
 }
 
 bool PreferencesDialog::isDefault()
 {
     return KConfigDialog::isDefault() && m_pluginSelector->isDefault();
 }
+
+void PreferencesDialog::enableButton(QDialogButtonBox::StandardButton standardButton)
+{
+    QPushButton *button =  buttonBox()->button(standardButton);
+    if (button) {
+        button->setEnabled(true);
+    }
+}
+
